@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CopyJob.cc,v 1.44 2009/03/20 12:25:06 lav Exp $ */
+/* $Id: CopyJob.cc,v 1.45 2009/04/27 07:45:25 lav Exp $ */
 
 #include <config.h>
 #include "CopyJob.h"
@@ -29,8 +29,12 @@
 
 #define waiting_num waiting.count()
 
+#define super Job
+
 int CopyJob::Do()
 {
+   if(!c)
+      return STALL;
    if(!fg_data)
       fg_data=c->GetFgData(fg);
    if(done)
@@ -146,6 +150,7 @@ CopyJob::CopyJob(FileCopy *c1,const char *name1,const char *op1)
    SetDispName();
 }
 
+
 const char *CopyJob::FormatBytesTimeRate(off_t bytes,double time_spent)
 {
    if(bytes<=0)
@@ -166,6 +171,15 @@ const char *CopyJob::FormatBytesTimeRate(off_t bytes,double time_spent)
 		     (long long)bytes),(long long)bytes);
 }
 
+void CopyJob::PrepareToDie()
+{
+   c=0;
+   super::PrepareToDie();
+}
+CopyJob::~CopyJob()
+{
+}
+#undef super
 
 // CopyJobEnv
 CopyJobEnv::CopyJobEnv(FileAccess *s,ArgV *a,bool cont1)
