@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: CopyJob.h,v 1.26 2008/11/27 05:56:10 lav Exp $ */
+/* $Id: CopyJob.h,v 1.29 2009/08/11 10:21:16 lav Exp $ */
 
 #ifndef COPYJOB_H
 #define COPYJOB_H
@@ -41,8 +41,11 @@ protected:
 
    void SetDispName();
 
+   void PrepareToDie();
+
 public:
    CopyJob(FileCopy *c1,const char *n,const char *op1);
+   ~CopyJob();
 
    void NoStatus() { no_status=true; }
    void NoStatusOnWrite() { no_status_on_write=true; }
@@ -55,8 +58,8 @@ public:
 
    void SuspendInternal() { c->SuspendSlave(); }
    void ResumeInternal()  { c->ResumeSlave(); }
-   void Fg() { c->Fg(); Job::Fg(); }
-   void Bg() { Job::Bg(); c->Bg(); }
+   void Fg() { if(c) c->Fg(); Job::Fg(); }
+   void Bg() { Job::Bg(); if(c) c->Bg(); }
 
    int AcceptSig(int sig);
    pid_t GetProcGroup() { return c?c->GetProcGroup():0; }
@@ -73,7 +76,7 @@ public:
    const char *GetETAStrSFromTime(time_t t) { return c->GetETAStrSFromTime(t); }
    void SetRange(off_t s,off_t lim) { c->SetRange(s,lim); }
    void SetRangeLimit(off_t lim) { return c->SetRangeLimit(lim); }
-   void SetDate(time_t d) { c->SetDate(d); }
+   void SetDate(const FileTimestamp& d) { c->SetDate(d); }
    void SetSize(off_t s)   { c->SetSize(s); }
    const SMTaskRef<FileCopy>& GetCopy() { return c; }
    const SMTaskRef<FileCopyPeer>& GetPut() { return c->put; }
