@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.cc,v 1.159 2008/11/27 05:56:11 lav Exp $ */
+/* $Id: FileAccess.cc,v 1.162 2009/07/21 11:30:34 lav Exp $ */
 
 #include <config.h>
 
@@ -105,57 +105,6 @@ FileAccess::~FileAccess()
    ListDel(FileAccess,chain,this,next);
 }
 
-void  FileAccess::Log2(int level,xstring& str)
-{
-   str.chomp('\n');
-   str.chomp('\r');
-   str.append('\n');
-   Log::global->Write(level,str);
-}
-void  FileAccess::Log3(int level,const char *prefix,const char *str0)
-{
-   xstring &str=xstring::get_tmp(prefix);
-   str.append(str0);
-   Log2(level,str);
-}
-void FileAccess::LogError(int level,const char *fmt,...)
-{
-   va_list v;
-   va_start(v,fmt);
-   xstring &str=xstring::get_tmp("**** ");
-   str.vappendf(fmt,v);
-   Log2(level,str);
-   va_end(v);
-}
-void FileAccess::LogNote(int level,const char *fmt,...)
-{
-   va_list v;
-   va_start(v,fmt);
-   xstring &str=xstring::get_tmp("---- ");
-   str.vappendf(fmt,v);
-   Log2(level,str);
-   va_end(v);
-}
-void FileAccess::LogRecv(int level,const char *line)
-{
-   Log3(level,"<--- ",line);
-}
-void FileAccess::LogSend(int level,const char *line)
-{
-   Log3(level,"---> ",line);
-}
-
-void FileAccess::NonBlock(int fd)
-{
-   int fl=fcntl(fd,F_GETFL);
-   fcntl(fd,F_SETFL,fl|O_NONBLOCK);
-}
-void FileAccess::CloseOnExec(int fd)
-{
-   fcntl(fd,F_SETFD,FD_CLOEXEC);
-}
-
-
 void  FileAccess::Open(const char *fn,int mode,off_t offs)
 {
 #ifdef OPEN_DEBUG
@@ -275,6 +224,23 @@ void FileAccess::Mkdir(const char *fn,bool allp)
    mkdir_p=allp;
 }
 
+StringSet *FileAccess::MkdirMakeSet()
+{
+   StringSet *set=new StringSet;
+   const char *sl=strchr(file,'/');
+   while(sl)
+   {
+      if(sl>file)
+      {
+	 xstring& tmp=xstring::get_tmp(file,sl-file);
+	 if(tmp.ne(".") && tmp.ne(".."))
+	    set->Append(tmp);
+      }
+      sl=strchr(sl+1,'/');
+   }
+   return set;
+}
+
 bool FileAccess::SameLocationAs(const FileAccess *fa) const
 {
    return SameSiteAs(fa);
@@ -818,6 +784,9 @@ FileAccess *FileAccess::New(const char *proto,const char *host,const char *port)
 {
    ClassInit();
 
+   if(proto==0)
+      proto="file";
+
    if(!strcmp(proto,"slot"))
    {
       const FA *session=ConnectionSlot::FindSession(host);
@@ -847,14 +816,15 @@ FileAccess *FileAccess::New(const char *proto,const char *host,const char *port)
 }
 FileAccess *FileAccess::New(const ParsedURL *u,bool dummy)
 {
-   FileAccess *s=New(u->proto,u->host);
+   const char *proto=u->proto?u->proto.get():"file";
+   FileAccess *s=New(proto,u->host);
    if(!s)
    {
       if(!dummy)
 	 return 0;
-      return new DummyNoProto(u->proto);
+      return new DummyNoProto(proto);
    }
-   if(strcmp(u->proto,"slot"))
+   if(strcmp(proto,"slot"))
       s->Connect(u->host,u->port);
    if(u->user)
       s->Login(u->user,u->pass);
@@ -1053,7 +1023,7 @@ void FileAccess::Path::Change(const char *new_path,bool new_is_file,const char *
 	 up_len--;
       if(strncmp(url_path,path,up_len))
       {
-	 Log::global->Format(0,"(BUG?) URL mismatch %s vs %s, dropping URL\n",url.get(),path.get());
+	 LogError(0,"(BUG?) URL mismatch %s vs %s, dropping URL\n",url.get(),path.get());
 	 url.set(0);
       }
    }
@@ -1084,7 +1054,7 @@ void FileAccess::Path::ExpandTilde(const Path &home)
       int pi=url::path_index(url);
       if(url[pi]=='/' && url[pi+1]=='~')
 	 pi++;
-      expand_tilde(url,home.url?home.url.get():url::encode(home.path,URL_PATH_UNSAFE),pi);
+      expand_tilde(url,home.url?home.url.get():url::encode(home.path,URL_PATH_UNSAFE).get(),pi);
    }
    expand_tilde(path,home.path);
 }
