@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileAccess.h,v 1.110 2008/11/27 05:56:11 lav Exp $ */
+/* $Id: FileAccess.h,v 1.113 2009/07/21 11:30:34 lav Exp $ */
 
 #ifndef FILEACCESS_H
 #define FILEACCESS_H
@@ -32,6 +32,7 @@
 #include "ResMgr.h"
 #include "FileSet.h"
 #include "ArgV.h"
+#include "ProtoLog.h"
 
 #define FILE_END     ((off_t)-1L)
 #define UNKNOWN_POS  ((off_t)-1L)
@@ -42,7 +43,7 @@ class NoGlob;
 class DirList;
 class FileAccessRef;
 
-class FileAccess : public SMTask, public ResClient
+class FileAccess : public SMTask, public ResClient, protected ProtoLog
 {
    static bool class_inited;
 public:
@@ -132,12 +133,6 @@ protected:
    FileTimestamp *opt_date;
    off_t  *opt_size;
 
-   static void NonBlock(int fd);
-   static void CloseOnExec(int fd);
-
-   static void Log2(int level,xstring& str);
-   static void Log3(int level,const char *prefix,const char *str);
-
    time_t try_time;
    int retries;
 
@@ -192,6 +187,8 @@ protected:
    FileAccess *FirstSameSite() { return NextSameSite(0); }
    FileAccess *NextSameSite(FileAccess *);
 
+   StringSet *MkdirMakeSet(); // splits the path for mkdir -p
+
    int device_prefix_len(const char *path);
 
 public:
@@ -371,11 +368,6 @@ public:
 
    static void ClassInit();
    static void ClassCleanup();
-
-   static void LogError(int level,const char *fmt,...) PRINTF_LIKE(2,3);
-   static void LogNote(int level,const char *fmt,...) PRINTF_LIKE(2,3);
-   static void LogRecv(int level,const char *line);
-   static void LogSend(int level,const char *line);
 };
 
 // shortcut
