@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: FileSet.cc,v 1.67 2008/11/27 05:56:14 lav Exp $ */
+/* $Id: FileSet.cc,v 1.70 2009/09/15 07:56:29 lav Exp $ */
 
 #include <config.h>
 #include "FileSet.h"
@@ -43,6 +43,10 @@
 #include "IdNameCache.h"
 #include "PatternSet.h"
 
+#ifdef HAVE_SYS_STATFS_H
+# include <sys/statfs.h>
+#endif
+
 #define fnum files.count()
 
 void  FileInfo::Merge(const FileInfo& f)
@@ -694,7 +698,13 @@ check_again:
       return;   // ignore other type files
 
    SetSize(st.st_size);
-   SetDate(st.st_mtime,0);
+   int prec=0;
+#if defined(HAVE_STATFS) && defined(MSDOS_SUPER_MAGIC)
+   struct statfs stfs;
+   if(statfs(name,&stfs)!=-1 && stfs.f_type==MSDOS_SUPER_MAGIC)
+      prec=1;  // MS-DOS fs has 2-second resolution
+#endif
+   SetDate(st.st_mtime,prec);
    SetMode(st.st_mode&07777);
    SetType(t);
    SetNlink(st.st_nlink);
@@ -782,7 +792,7 @@ FileInfo *FileInfo::parse_ls_line(const char *line_c,const char *tz)
    t = NEXT_TOKEN;
    if(!t)
       ERR;
-   if(isdigit(*t))
+   if(isdigit((unsigned char)*t))
    {
       // it's size, so the previous was group:
       fi->SetGroup(group_or_size);
@@ -823,12 +833,9 @@ FileInfo *FileInfo::parse_ls_line(const char *line_c,const char *tz)
    date.tm_hour=date.tm_min=0;
    date.tm_sec=30;
    int prec=30;
-   if(strlen(t)==5)
-   {
-      if(sscanf(t,"%2d:%2d",&date.tm_hour,&date.tm_min)!=2)
-	 ERR;
+
+   if(sscanf(t,"%2d:%2d",&date.tm_hour,&date.tm_min)==2)
       date.tm_year=guess_year(date.tm_mon,date.tm_mday,date.tm_hour,date.tm_min) - 1900;
-   }
    else
    {
       if(day_of_month+strlen(day_of_month)+1 == t)
@@ -837,6 +844,7 @@ FileInfo *FileInfo::parse_ls_line(const char *line_c,const char *tz)
       /* We don't know the hour.  Set it to something other than 0, or
        * DST -1 will end up changing the date. */
       date.tm_hour = 12;
+      date.tm_min=0;
       date.tm_sec=0;
       prec=12*HOUR;
    }
@@ -847,7 +855,7 @@ FileInfo *FileInfo::parse_ls_line(const char *line_c,const char *tz)
    if(!name)
       ERR;
 
-   // there are ls which outputs extra space after year.
+   // there are ls which output extra space after year.
    if(year_anomaly && *name==' ')
       name++;
 
