@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,16 +18,15 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Fish.h,v 1.28 2007/09/10 10:27:39 lav Exp $ */
+/* $Id: Fish.h,v 1.30 2008/11/27 05:56:16 lav Exp $ */
 
 #ifndef FISH_H
 #define FISH_H
 
-#include "NetAccess.h"
-#include "PtyShell.h"
+#include "SSH_Access.h"
 #include "StringSet.h"
 
-class Fish : public NetAccess
+class Fish : public SSH_Access
 {
    enum state_t
    {
@@ -42,8 +41,6 @@ class Fish : public NetAccess
    };
 
    state_t state;
-   bool received_greeting;
-   int  password_sent;
 
    void Init();
 
@@ -52,10 +49,6 @@ class Fish : public NetAccess
    void	 SendMethod();
    void	 SendArrayInfoRequests();
 
-   Ref<IOBuffer> send_buf;
-   Ref<IOBuffer> recv_buf;
-   Ref<PtyShell> ssh;
-
    void Disconnect();
    int IsConnected() const
       {
