@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Job.h,v 1.31 2007/09/10 10:32:06 lav Exp $ */
+/* $Id: Job.h,v 1.36 2009/08/13 09:42:44 lav Exp $ */
 
 #ifndef JOB_H
 #define JOB_H
@@ -32,6 +32,8 @@
 #include "fg.h"
 #include "FileAccess.h"
 
+#define JobRef SMTaskRef // it is basically the same
+
 class Job : public SMTask
 {
    static void SortJobs();
@@ -41,8 +43,10 @@ class Job : public SMTask
 
 protected:
    bool fg;
-   FgData *fg_data;
+   Ref<FgData> fg_data;
 
+   bool job_prepared_to_die;
+   void PrepareToDie();
    virtual ~Job();
 
 public:
@@ -52,7 +56,8 @@ public:
    xarray<Job*> waiting;
 
    void AddWaiting(Job *);
-   void RemoveWaiting(Job *);
+   template<class T> void AddWaiting(const JobRef<T>& r) { AddWaiting(r.get_non_const()); }
+   void RemoveWaiting(const Job *);
    void ReplaceWaiting(Job *from,Job *to);
 
    void SetParent(Job *j) { parent=j; }
@@ -154,6 +159,5 @@ public:
    void Bg();
 };
 
-#define JobRef SMTaskRef // it is basically the same
 
 #endif /* JOB_H */
