@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: Resolver.cc,v 1.82 2008/11/27 05:56:26 lav Exp $ */
+/* $Id: Resolver.cc,v 1.85 2009/07/17 13:04:46 lav Exp $ */
 
 #include <config.h>
 
@@ -139,7 +139,7 @@ int   Resolver::Do()
       cache->Find(hostname,portname,defport,service,proto,&a,&n);
       if(a && n>0)
       {
-	 FA::LogNote(10,"dns cache hit");
+	 LogNote(10,"dns cache hit");
 	 addr.nset(a,n);
 	 done=true;
 	 return MOVED;
@@ -163,7 +163,7 @@ int   Resolver::Do()
 	 fcntl(pipe_to_child[0],F_SETFD,FD_CLOEXEC);
 	 fcntl(pipe_to_child[1],F_SETFD,FD_CLOEXEC);
 	 m=MOVED;
-	 FA::LogNote(4,_("Resolving host address..."));
+	 LogNote(4,_("Resolving host address..."));
       }
 
       if(!w && !buf)
@@ -205,7 +205,7 @@ int   Resolver::Do()
    {
       if(!buf)
       {
-	 FA::LogNote(4,_("Resolving host address..."));
+	 LogNote(4,_("Resolving host address..."));
 	 buf=new IOBuffer(IOBuffer::GET);
 	 DoGethostbyname();
 	 if(deleting)
@@ -254,7 +254,7 @@ int   Resolver::Do()
       if(use_fork)
       {
 	 // e.g. under gdb child fails.
-	 FA::LogError(4,"child failed, retrying with dns:use-fork=no");
+	 LogError(4,"child failed, retrying with dns:use-fork=no");
 	 use_fork=false;
 	 buf=0;
 	 return MOVED;
@@ -279,7 +279,7 @@ int   Resolver::Do()
 	    report.append(", ");
       }
    }
-   FA::LogNote(4,"%s",report.get());
+   LogNote(4,"%s",report.get());
 
    return MOVED;
 }
@@ -291,7 +291,7 @@ void Resolver::MakeErrMsg(const char *f)
    done=true;
 }
 
-void Resolver::AddAddress(int family,const char *address,int len)
+void Resolver::AddAddress(int family,const char *address,int len, unsigned int scope)
 {
    sockaddr_u add;
    memset(&add,0,sizeof(add));
@@ -315,9 +315,12 @@ void Resolver::AddAddress(int family,const char *address,int len)
          return;
       memcpy(&add.in6.sin6_addr,address,len);
       add.in6.sin6_port=port_number;
-#ifdef HAVE_STRUCT_SOCKADDR_SA_LEN
+# ifdef HAVE_STRUCT_SOCKADDR_IN6_SIN6_SCOPE_ID
+      add.in6.sin6_scope_id=scope;
+# endif
+# ifdef HAVE_STRUCT_SOCKADDR_SA_LEN
       add.sa.sa_len=sizeof(add.in6);
-#endif
+# endif
       break;
 #endif
 
@@ -693,6 +696,7 @@ void Resolver::LookupOne(const char *name)
       struct sockaddr_in6   *inet6_addr;
       const char	    *addr_data;
       int		    addr_len;
+      unsigned int          addr_scope;
 
       memset(&a_hint, 0, sizeof(a_hint));
       a_hint.ai_flags	    = AI_PASSIVE;
@@ -711,6 +715,7 @@ void Resolver::LookupOne(const char *name)
 		  continue;
 
 	       sockname	= a_res->ai_addr;
+	       addr_scope = 0;
 
 	       switch(a_res->ai_family)
 	       {
@@ -722,12 +727,15 @@ void Resolver::LookupOne(const char *name)
 	       case AF_INET6:
 		  inet6_addr  = (sockaddr_in6 *)sockname;
 		  addr_data   = (const char *)&(inet6_addr->sin6_addr.s6_addr);
+#ifdef HAVE_STRUCT_SOCKADDR_IN6_SIN6_SCOPE_ID
+		  addr_scope  = inet6_addr->sin6_scope_id;
+#endif
 		  addr_len    = sizeof(inet6_addr->sin6_addr.s6_addr);
 		  break;
 	       default:
 		  continue;
 	       }
-	       AddAddress(a_res->ai_family, addr_data, addr_len);
+	       AddAddress(a_res->ai_family, addr_data, addr_len, addr_scope);
 	    }
 	 }
 
@@ -773,7 +781,7 @@ void Resolver::LookupOne(const char *name)
       {
 	 const char * const *a;
 	 for(a=ha->h_addr_list; *a; a++)
-	    AddAddress(ha->h_addrtype, *a, ha->h_length);
+	    AddAddress(ha->h_addrtype, *a, ha->h_length, 0);
 	 retries=0;
 	 af_index++;
 # if defined(HAVE_GETIPNODEBYNAME)
