@@ -1,11 +1,11 @@
 /*
  * lftp and utils
  *
- * Copyright (c) 1998 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1998-2005 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -18,35 +18,30 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: buffer_ssl.h,v 1.1 2001/04/04 07:22:13 lav Exp $ */
+/* $Id: buffer_ssl.h,v 1.10 2008/11/27 05:56:34 lav Exp $ */
 
 #ifndef BUFFER_SSL_H
 #define BUFFER_SSL_H
 
 #include "buffer.h"
 
-#ifdef USE_SSL
-# include <openssl/ssl.h>
+#if USE_SSL
+#include "lftp_ssl.h"
 class IOBufferSSL : public IOBuffer
 {
-   SSL *ssl;
-   bool ssl_connected;
-   bool do_connect;
-   bool close_later;
+   Ref<lftp_ssl> my_ssl;
+   const Ref<lftp_ssl>& ssl;
 
    int Get_LL(int size);
    int Put_LL(const char *buf,int size);
-
-protected:
-   ~IOBufferSSL();
+   int PutEOF_LL();
 
 public:
-   IOBufferSSL(SSL *s,dir_t m) : IOBuffer(m)
-      { ssl=s; ssl_connected=false; do_connect=false; close_later=false; }
-   void DoConnect()	{ ssl_connected=false; do_connect=true; }
-   void SetConnected()	{ ssl_connected=true; }
-   void CloseLater()	{ close_later=true; }
+   IOBufferSSL(lftp_ssl *s,dir_t m) : IOBuffer(m), my_ssl(s), ssl(my_ssl) {}
+   IOBufferSSL(const Ref<lftp_ssl>& s,dir_t m) : IOBuffer(m), ssl(s) {}
+   ~IOBufferSSL();
    int Do();
+   bool Done() { return IOBuffer::Done() && ssl->handshake_done; }
 };
 #endif
 
