@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: commands.cc,v 1.294.2.1 2009/07/21 09:30:26 lav Exp $ */
+/* $Id: commands.cc,v 1.297 2009/08/11 07:05:50 lav Exp $ */
 
 #include <config.h>
 
@@ -93,7 +93,7 @@ CMD(ver);   CMD(close);  CMD(bookmark);CMD(lftp);
 CMD(echo);  CMD(suspend);CMD(sleep);   CMD(slot);
 CMD(at);    CMD(find);   CMD(command); CMD(module);
 CMD(lpwd);  CMD(glob);	 CMD(chmod);   CMD(queue);
-CMD(repeat);CMD(get1);   CMD(tasks);
+CMD(repeat);CMD(get1);   CMD(tasks);   CMD(torrent);
 
 #ifdef MODULE_CMD_MIRROR
 # define cmd_mirror 0
@@ -103,6 +103,9 @@ CMD(repeat);CMD(get1);   CMD(tasks);
 # define cmd_at     0
 # define cmd_repeat 0
 #endif
+#ifdef MODULE_CMD_TORRENT
+# define cmd_torrent 0
+#endif
 
 #define S "\001"
 
@@ -118,7 +121,7 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
 	 N_("Define or undefine alias <name>. If <value> omitted,\n"
 	 "the alias is undefined, else is takes the value <value>.\n"
          "If no argument is given the current aliases are listed.\n")},
-   {"anon",    cmd_anon,   "anon",
+   {"anon",    cmd_anon,   0,
 	 N_("anon - login anonymously (by default)\n")},
    {"at",      cmd_at},
    {"bookmark",cmd_bookmark,N_("bookmark [SUBCMD]"),
@@ -458,6 +461,7 @@ const struct CmdExec::cmd_rec CmdExec::static_cmd_table[]=
    {"source",  cmd_source, N_("source <file>"),
 	 N_("Execute commands recorded in file <file>\n")},
    {"suspend", cmd_suspend},
+   {"torrent", cmd_torrent, N_("torrent [-O <dir>] <file>")},
    {"user",    cmd_user,   N_("user <user|URL> [<pass>]"),
 	 N_("Use specified info for remote login. If you specify URL, the password\n"
 	 "will be cached for future usage.\n")},
@@ -987,9 +991,9 @@ Job *CmdExec::builtin_open()
 	    if(nrc)
 	    {
 	       if(!user)
-		  FA::LogNote(3,"using user `%s' and password from ~/.netrc",nrc->user.get());
+		  ProtoLog::LogNote(3,"using user `%s' and password from ~/.netrc",nrc->user.get());
 	       else
-		  FA::LogNote(3,"using password from ~/.netrc");
+		  ProtoLog::LogNote(3,"using password from ~/.netrc");
 	       user=nrc->user;
 	       pass=nrc->pass;
 	    }
@@ -2525,6 +2529,10 @@ void CmdExec::print_cmd_index()
    int i=0;
    const cmd_rec *cmd_table=dyn_cmd_table?dyn_cmd_table.get():static_cmd_table;
    const int count=dyn_cmd_table?dyn_cmd_table.count():static_cmd_table_length;
+   int width=fd_width(1);
+   int pos=0;
+   const int align=37;
+   const int first_align=4;
    while(i<count)
    {
       while(i<count && !cmd_table[i].short_desc)
@@ -2533,16 +2541,24 @@ void CmdExec::print_cmd_index()
 	 break;
       const char *c1=gettext(cmd_table[i].short_desc);
       i++;
-      while(i<count && !cmd_table[i].short_desc)
-	 i++;
-      if(i<count)
-      {
-	 printf("\t%-35s %s\n",c1,gettext(cmd_table[i].short_desc));
-	 i++;
+      int w1=mbswidth(c1,0);
+
+      int pad=0;
+      if(pos<first_align)
+	 pad=first_align-pos;
+      else if(pos>first_align)
+	 pad=align-(pos-first_align)%align;
+      if(pos>first_align && pos+pad+w1>=width) {
+	 printf("\n");
+	 pos=0;
+	 pad=first_align;
       }
-      else
-	 printf("\t%s\n",c1);
+
+      printf("%*s%s",pad,"",c1);
+      pos+=pad+w1;
    }
+   if(pos>0)
+      printf("\n");
 }
 
 CMD(help)
