@@ -5,7 +5,7 @@
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -293,12 +293,13 @@ void lftp_ssl_gnutls::load_keys()
    }
    gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, cred);
 }
-lftp_ssl_gnutls::~lftp_ssl_gnutls()
+void lftp_ssl_gnutls::shutdown()
 {
-#if 0
    if(handshake_done)
       gnutls_bye(session,GNUTLS_SHUT_RDWR);  // FIXME - E_AGAIN
-#endif
+}
+lftp_ssl_gnutls::~lftp_ssl_gnutls()
+{
    if(cred)
       gnutls_certificate_free_credentials(cred);
    gnutls_deinit(session);
@@ -723,6 +724,10 @@ void lftp_ssl_openssl::global_deinit()
    instance=0;
 }
 
+#ifndef SSL_OP_NO_TICKET
+# define SSL_OP_NO_TICKET 0
+#endif
+
 lftp_ssl_openssl_instance::lftp_ssl_openssl_instance()
 {
    crl_store=0;
@@ -745,7 +750,7 @@ lftp_ssl_openssl_instance::lftp_ssl_openssl_instance()
 #else
    SSLeay_add_ssl_algorithms();
    ssl_ctx=SSL_CTX_new(SSLv23_client_method());
-   SSL_CTX_set_options(ssl_ctx, SSL_OP_ALL);
+   SSL_CTX_set_options(ssl_ctx, SSL_OP_ALL|SSL_OP_NO_TICKET);
    SSL_CTX_set_verify(ssl_ctx,SSL_VERIFY_PEER,lftp_ssl_openssl::verify_callback);
 //    SSL_CTX_set_default_passwd_cb(ssl_ctx,lftp_ssl_passwd_callback);
 
@@ -831,12 +836,13 @@ void lftp_ssl_openssl::load_keys()
       }
    }
 }
-lftp_ssl_openssl::~lftp_ssl_openssl()
+void lftp_ssl_openssl::shutdown()
 {
-#if 0
    if(handshake_done)
       SSL_shutdown(ssl);
-#endif
+}
+lftp_ssl_openssl::~lftp_ssl_openssl()
+{
    SSL_free(ssl);
 }
 
