@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: mgetJob.cc,v 1.28 2008/11/27 05:56:40 lav Exp $ */
+/* $Id: mgetJob.cc,v 1.29 2009/04/27 07:54:59 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -169,10 +169,11 @@ int mgetJob::Do()
 	 m_args=0;
 	 if(mkdir_args)
 	 {
+	    xstring_ca cmdline(mkdir_args->Combine());
 	    mkdir_job=new mkdirJob(Clone(),mkdir_args.borrow());
+	    mkdir_job->cmdline.set_allocated(cmdline.borrow());
 	    mkdir_job->BeQuiet();
 	    AddWaiting(mkdir_job);
-	    mkdir_job->cmdline.set_allocated(mkdir_args->Combine());
 	 }
 	 return MOVED;
       }
