@@ -18,7 +18,7 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-/* $Id: pgetJob.cc,v 1.51 2008/11/27 05:56:44 lav Exp $ */
+/* $Id: pgetJob.cc,v 1.53 2009/03/17 10:59:59 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -365,20 +365,20 @@ void pgetJob::SaveStatus()
       return;
 
    off_t size=GetSize();
-   fprintf(f,"size=%lld\n",size);
+   fprintf(f,"size=%lld\n",(long long)size);
 
    int i=0;
-   fprintf(f,"%d.pos=%lld\n",i,GetPos());
+   fprintf(f,"%d.pos=%lld\n",i,(long long)GetPos());
    if(!chunks)
       goto out_close;
-   fprintf(f,"%d.limit=%lld\n",i,limit0);
+   fprintf(f,"%d.limit=%lld\n",i,(long long)limit0);
    for(int chunk=0; chunk<chunks.count(); chunk++)
    {
       if(chunks[chunk]->Done())
 	 continue;
       i++;
-      fprintf(f,"%d.pos=%lld\n",i,chunks[chunk]->GetPos());
-      fprintf(f,"%d.limit=%lld\n",i,chunks[chunk]->limit);
+      fprintf(f,"%d.pos=%lld\n",i,(long long)chunks[chunk]->GetPos());
+      fprintf(f,"%d.limit=%lld\n",i,(long long)chunks[chunk]->limit);
    }
 out_close:
    fclose(f);
@@ -465,7 +465,7 @@ void pgetJob::LoadStatus()
       goto out_close;
    for(i=0; i<num_of_chunks; i++)
    {
-      ChunkXfer *c=NewChunk(GetName(),pos[i],limit[i]);
+      ChunkXfer *c=NewChunk(GetName(),pos[i+1],limit[i+1]);
       c->SetParentFg(this,false);
       chunks.append(c);
    }
