@@ -43,8 +43,8 @@ public:
    char *Combine(const char *home=0,bool use_rfc1738=true);
 };
 
-# define URL_UNSAFE " <>\"%{}|\\^[]`"
-# define URL_PATH_UNSAFE URL_UNSAFE"#;?"
+# define URL_UNSAFE " <>\"'%{}|\\^[]`"
+# define URL_PATH_UNSAFE URL_UNSAFE"#;?&+"
 # define URL_HOST_UNSAFE URL_UNSAFE":/"
 # define URL_PORT_UNSAFE URL_UNSAFE"/"
 # define URL_USER_UNSAFE URL_UNSAFE"/:@"
@@ -68,10 +68,12 @@ public:
 
    // encode unsafe chars as %XY
    static char *encode_string(const char *,char *buf=0,const char *u=URL_UNSAFE);
-   static const char *encode(const char *s,const char *unsafe);
+   static xstring& encode(const char *s,int len,const char *unsafe);
+   static xstring& encode(const xstring &s,const char *unsafe) { return encode(s,s.length(),unsafe); }
+   static xstring& encode(const char *s,const char *unsafe) { return encode(s,strlen(s),unsafe); }
    // reverse; done in-place; returns length.
    static int decode_string(char *);
-   static const char *decode(const char *);
+   static xstring& decode(const char *);
 
    static bool is_url(const char *p);
    static int path_index(const char *p);
